@@ -4,8 +4,6 @@
 #'
 #' @param max_time Maximum wait time in seconds
 #'
-#' @export
-#'
 #' @return Returns TRUE if connection is established and FALSE
 #' otherwise.
 #'
@@ -13,6 +11,8 @@
 #' \donttest{
 #' can_arxiv_connect(2)
 #' }
+#'
+#' @export
 can_arxiv_connect <-
     function(max_time=5) # maximum wait time in seconds
 {
@@ -39,7 +39,7 @@ can_arxiv_connect <-
 
     # check for general http error
     status <- httr::http_status(z)
-    if(status$category != "success") {
+    if(status$category != "success" && status$category != "Success") {
         httr::warn_for_status(z)
         return(FALSE)
     }
